@@ -133,17 +133,20 @@ public class RowEvaluator {
         public boolean isValid( String value ) {
             try {
                 ParsedFloat pf = parseFloating( value );
-                if ( pf.sigFig > 6 ||
-                     ( Float.isInfinite( (float) pf.dValue ) &&
-                       ! Double.isInfinite( pf.dValue ) ) ) {
-                    return false;
-                }
-                return true;
+                double dval = pf.dValue;
+                return dval == 0
+                    || Double.isNaN( dval )
+                    || Double.isInfinite( dval )
+                    || ( pf.sigFig <= 6 && isSinglePrecision( dval ) );
             }
             catch ( NumberFormatException e ) {
                 return false;
             }
         }
+        private boolean isSinglePrecision( double dval ) {
+            double absVal = Math.abs( dval );
+            return absVal > Float.MIN_NORMAL && absVal < Float.MAX_VALUE;
+        }
     };
 
     /** Decoder for doubles. */
@@ -252,7 +255,7 @@ public class RowEvaluator {
      * @throws  TableFormatException  if the number of elements in
      *          <tt>row</tt> is not the same as on the first call
      */
-    public void submitRow( List row ) throws TableFormatException {
+    public void submitRow( List<String> row ) throws TableFormatException {
         nrow_++;
         if ( ncol_ < 0 ) {
             init( row.size() );
@@ -264,7 +267,7 @@ public class RowEvaluator {
         }
         for ( int icol = 0; icol < ncol_; icol++ ) {
             boolean done = false;
-            String cell0 = (String) row.get( icol );
+            String cell0 = row.get( icol );
             int leng0 = cell0 == null ? 0 : cell0.length();
             String cell = cell0 == null ? "" : cell0.trim();
             int leng = cell.length();
@@ -516,14 +519,14 @@ public class RowEvaluator {
      * object.
      */
     public static abstract class Decoder {
-        private final Class clazz_;
+        private final Class<?> clazz_;
 
         /**
          * Constructor.
          *
          * @param   clazz  class of object to be returned by decode method
          */
-        public Decoder( Class clazz ) {
+        public Decoder( Class<?> clazz ) {
             clazz_ = clazz;
         }
 
